from __future__ import annotations

from .extension import SQLAlchemy


__version__ = "2.0.0"

__all__ = ["SQLAlchemy"]
